/*
 *
 *  Copyright 2016-2017 Red Hat, Inc, and individual contributors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

'use strict';

// https://docs.openshift.com/online/rest_api/kubernetes_v1.html#v1-service
const log = require('./common-log')();
const { awaitRequest } = require('./helpers');

module.exports = async function getServices (config, serviceResource) {
  const service = await awaitRequest(config.openshiftRestClient.api.v1.ns(config.namespace.name).service(serviceResource.metadata.name).get());
  if (service.code === 404) {
    // There isn't a service yet, so we need to create one
    log.info(`creating new service ${serviceResource.metadata.name}`);
    return config.openshiftRestClient.api.v1.ns(config.namespace.name).service.post({ body: serviceResource });
  }

  log.info(`using existing service ${service.body.metadata.name}`);
  return service;
};
